@@ -11,13 +11,11 @@
  * ======================================================
  */
 
-#ifndef _DEP_TABLE_H
-#define _DEP_TABLE_H
+#ifndef DEP_TABLE_H
+#define DEP_TABLE_H
 
 #include "LString.h"
-#include <stdio.h>
-
-class LString;
+#include <cstdio>
 
 ///
 class DepTable {
@@ -25,30 +23,32 @@ public:
 	///
 	DepTable();
 	///
-	DepTable(LString const &f,
-		 unsigned long one,
-		 unsigned long two);
-	///
 	/** This one is a little bit harder since we need the absolute
 	  filename. Should we insert files with .sty .cls etc as
 	  extension? */
-	void insert(LString const &f,
-		    unsigned long one=0,
-		    unsigned long two=0);
+	void insert(string const &f,
+		    bool upd = false,
+		    unsigned long one = 0,
+		    unsigned long two = 0);
 	///
 	void update();
 
 	///
-	void write(LString const &f);
+	void write(string const &f);
 	///
-	void read(LString const &f);
+	void read(string const &f);
 	/// returns true if any of the files has changed
 	bool sumchange();
 	///
-	bool haschanged(LString const &fil);
+	bool haschanged(string const &fil);
 private:
 	///
-	LString file;
+	DepTable(string const &f,
+		 bool upd,
+		 unsigned long one,
+		 unsigned long two);
+	///
+	string file;
 	/// The files new checksum
 	unsigned long new_sum;
 	/// The files old checksum
