@@ -9,6 +9,15 @@
 *           Lars Gullik Bjnnes
 *
 *======================================================*/
+ 
+// Change Log:
+// ===========
+// 23/03/98   Heinrich Bauer (heinrich.bauer@t-mobil.de)
+// Spots marked "changed Heinrich Bauer, 23/03/98" modified due to the
+// following bug: dvi file export did not work after printing (or previewing)
+// and vice versa as long as the same file was concerned. This happened
+// every time the LyX-file was left unchanged between the two actions mentioned
+// above.
 
 #ifndef _BUFFER_H_
 #define _BUFFER_H_
@@ -36,7 +45,7 @@ struct DEPCLEAN {
 	///
 	bool clean;
 	///
-	LString master;
+	string master;
 	///
 	DEPCLEAN *next;
 };
@@ -51,7 +60,7 @@ public:
 	/**@name Constructors and destructor */
 	//@{
 	///
-	Buffer(LString const & file, LyXRC * lyxrc = NULL, bool b= false);
+	Buffer(string const & file, LyXRC * lyxrc = 0, bool b= false);
 	
 	///
 	~Buffer();
@@ -122,44 +131,55 @@ public:
 	bool readLyXformat2(LyXLex &,LyXParagraph *par = 0);
 
 	/// Inserts a lyx file at cursor position. Returns false if it fails.
-	bool insertLyXFile(LString const & filename);
+	bool insertLyXFile(string const & filename);
 
 	/// Write file. Returns false if unsuccesful.
-	bool writeFile(LString const &, bool);
+	bool writeFile(string const &, bool);
 	
 	///
-	void writeFileAscii(LString const & , int);
+	void writeFileAscii(string const & , int);
 	
 	///
-	void makeLaTeXFile(LString const & filename,
-			   LString const & original_path,
+	void makeLaTeXFile(string const & filename,
+			   string const & original_path,
 			   bool nice, bool only_body = false);
 
 	///
 	int runLaTeX();
 
+        ///
+        int runLiterate();
+
+        ///
+        int buildProgram();
+
 	///
 	int runChktex();
 
 	///
-	void makeLinuxDocFile(LString const & filename, int column);
+	void makeLinuxDocFile(string const & filename, int column);
+	///
+	void makeDocBookFile(string const & filename, int column);
 
 	/// returns the main language for the buffer (document)
-	LString GetLanguage() const {
+	string GetLanguage() const {
 		return params.language;
 	}
 	
 	///
 	bool isLyxClean() const { return lyx_clean; }
 	
-	///
-	bool isDviClean() const { return dvi_clean; }
+	/// changed Heinrich Bauer, 23/03/98
+	bool isDviClean();
 	
+        ///
+        bool isNwClean() const { return nw_clean; }
+       
 	///
 	bool isBakClean() const { return bak_clean; }
 	
 	///
-	bool isDepClean(LString const & name) const;
+	bool isDepClean(string const & name) const;
 	
 	///
 	void markLyxClean() { 
@@ -172,25 +192,33 @@ public:
 		bak_clean = true;
 	}
 
-	///
-	void markDviClean() { dvi_clean = true; }
+	/// changed Heinrich Bauer, 23/03/98
+	void markDviClean();
 	
+        ///
+        void markNwClean() { nw_clean = true; }
+       
 	///
 	void markBakClean() { bak_clean = true; }
 	
 	///
-	void markDepClean(LString const & name);
+	void markDepClean(string const & name);
 	
 	///
-	void markDviDirty() { dvi_clean = false; }
+	void markDviDirty();
 	
+        ///
+        void markNwDirty() { nw_clean = false; }
+       
 	///
 	void markDirty() {
 		if (lyx_clean) {
 			lyx_clean = false;
 			updateTitles();
 		}
-		dvi_clean = false;
+		dvi_clean_tmpd = false;
+		dvi_clean_orgd = false;
+                nw_clean = false;
 		bak_clean = false;
 		DEPCLEAN* tmp = dep_clean;
 		while (tmp) {
@@ -200,10 +228,13 @@ public:
 	}
 
 	///
-	LString getFileName() const { return filename; }
+	string getFileName() const { return filename; }
 
 	/// Change name of buffer. Updates "read-only" flag.
-	void setFileName(LString const & newfile);
+	void setFileName(string const & newfile);
+
+	/// Name of the document's parent
+	void setParentName(string const &);
 
 	/// Is buffer read-only?
 	bool isReadonly() { return read_only; }
@@ -225,6 +256,12 @@ public:
 	bool isLatex();
 	/// returns true if the buffer contains a LinuxDoc document
 	bool isLinuxDoc();
+	/// returns true if the buffer contains a DocBook document
+	bool isDocBook();
+	/// returns true if the buffer contains either a LinuxDoc or DocBook document
+	bool isSGML();
+        /// returns true if the buffer contains a Wed document
+        bool isLiterate();
 
 	///
 	void setPaperStuff();
@@ -246,18 +283,20 @@ public:
 	/** Insert an inset into the buffer
 	  Insert inset into buffer, placing it in a layout of lout,
 	  if no_table make sure that it doesn't end up in a table. */
-	void insertInset(Inset *, LString const &lout=LString(), 
+	void insertInset(Inset *, string const &lout=string(), 
 			 bool no_table = false);
 
         ///
         void setCursorFromRow (int);
 
 	///
-	LString getIncludeonlyList(char delim=',');
+	string getIncludeonlyList(char delim=',');
 	///
-	LString getReferenceList(char delim='|');
+	string getReferenceList(char delim='|');
 	///
-	bool gotoLabel(const LString&);
+	string getBibkeyList(char delim='|');
+	///
+	bool gotoLabel(const string&);
 
 	/// removes all autodeletable insets
 	bool removeAutoInsets();
@@ -293,10 +332,10 @@ public:
 	LyXVC lyxvc;
 
 	/// where the temporaries go if we want them
-	LString tmppath;
+	string tmppath;
 
 	///
-	LString filepath;
+	string filepath;
 
 	/** While writing as LaTeX, tells whether we are
 	    doing a 'nice' LaTeX file */
@@ -323,33 +362,23 @@ private:
 	void insertErrors(TeXErrors &);
 	
         ///
-        void linuxDocHandleFootnote(FILE *file,LyXParagraph* &par);
+        void linuxDocHandleFootnote(FILE *file,LyXParagraph* &par, int const depth);
         ///
-        bool linuxDocConvertChar(char c, LString &sgml_string);
+	void DocBookHandleCaption(FILE *file, string &inner_tag,
+				  int const depth, int desc_on,
+				  LyXParagraph* &par);
+        ///
+	void DocBookHandleFootnote(FILE *file,LyXParagraph* &par, int const depth);
 	///
-        void sgmlOpenTag(FILE * file,int depth,LString & latexname);
+        void sgmlOpenTag(FILE * file,int depth,string & latexname);
         ///
-        void sgmlCloseTag(FILE * file,int depth,LString & latexname);
+        void sgmlCloseTag(FILE * file,int depth,string & latexname);
 	///
 	void LinuxDocError(LyXParagraph *par, int pos, char const *message);
         ///
-	void SimpleLinuxDocOnePar(FILE *file, LyXParagraph *par, int desc_on);
-
-	/** Gets next LinuxDoc parameter.
-	  
-	  This is one of the methods I don't understand. What is its
-	  purpose? Can somebody explain please?
-          Yes. It's used in multi-inset-Insets ;-). Terrible. Should be 
-          redesigned, if we switch to LaTeX-based LyX-file. But at 
-          moment, e.g. URL-Insets split up into three inset-parts. 
-          Firstly \url{. Then comes text [text1]. After this as second
-          inset {} and again "normal" text[text2]. And a closing (third)
-          } - Inset. GetNextParameter() now reads a text inbetween
-          to Insets and handles further insets, which are allowed to 
-          arise inside such a construction.
-	 */
-	int GetNextParameter(LyXParagraph *par, int pos,
-			     LString &buffer, bool convert);
+	void SimpleLinuxDocOnePar(FILE *file, LyXParagraph *par, int desc_on, int const depth);
+        ///
+	void SimpleDocBookOnePar(string &file, string &extra, LyXParagraph *par, int & desc_on, int const depth);
 
 	/// LinuxDoc.
 	void push_tag(FILE *file, char const *tag, int& pos, char stack[5][3]);
@@ -366,8 +395,16 @@ private:
 	/// is autosave needed
 	bool bak_clean;
 	
-	/// do we need to run LaTeX
-	bool dvi_clean;
+	/// do we need to run LaTeX, changed 23/03/98, Heinrich Bauer
+	/// We have to distinguish between TeX-runs executed in the original
+	/// directory (in which the original LyX-file resides) and TeX-runs
+	/// executed in a temporary directory. The first situation is valid
+	/// for a dvi-export, the latter one for printing or previewing.
+	bool dvi_clean_orgd;
+	bool dvi_clean_tmpd;
+
+        /// do we need to run weave/tangle
+        bool nw_clean;
 
 	/// is regenerating .tex necessary
 	DEPCLEAN *dep_clean;
@@ -376,7 +413,7 @@ private:
 	bool read_only;
 
 	/// name of the file the buffer is associated with.
-	LString filename;
+	string filename;
 
 	/// Format number of buffer
 	float format;
@@ -420,4 +457,12 @@ void Buffer::InsetWakeup()
     }	
 }
 
+
+inline  
+void Buffer::setParentName(string const &name)
+{
+    params.parentname = name;    
+}
+
+
 #endif
