@@ -1,6 +1,6 @@
 // -*- C++ -*-
-#ifndef _LYXFR1_H
-#define _LYXFR1_H
+#ifndef LYXFR1_H
+#define LYXFR1_H
 
 #ifdef __GNUG__
 #pragma interface
@@ -27,15 +27,17 @@ public:
 	virtual void StartSearch();
 
 	///
-	virtual void SearchCB(bool fForward);
+	virtual bool SearchCB(bool fForward);
 	///
 	virtual void SearchReplaceCB();
+	///
+	virtual void SearchReplaceAllCB();
 protected:
 	/// Set by IsSearchStringInText:
 	int	iLenSelected;
 
-        /// Direction we are searching:
-        bool searchForward;
+	/// Direction we are searching:
+	bool searchForward;
     
 	///
 	bool SearchForward(LyXText *lt);
