@@ -15,9 +15,5 @@
 #ifndef NT_DEFINES_H
 #define NT_DEFINES_H
 
-#define readlink(s,t,l) (strcpy(t,s),strlen(t))
-#define mkfifo(p,m) (0) /* LyXserver is temporary disabled. */
-#define lstat stat
-#include <sys/socket.h>
 
 #endif /* NT_DEFINES_H */
