@@ -35,11 +35,11 @@ public:
 	///
 	Toolbar()
 	{
-		owner = NULL;
+		owner = 0;
 		sxpos = 0;
 		sypos = 0;
-		bubble_timer = NULL;
-		combox = NULL;
+		bubble_timer = 0;
+		combox = 0;
 		reset();
 		init(); // set default toolbar.
 	}
@@ -50,7 +50,7 @@ public:
 	}
 	
 	///
-	int get_toolbar_func(LString const & func);
+	int get_toolbar_func(string const & func);
 	
         /// The special toolbar actions
 	enum  TOOLBARITEMS {
@@ -78,7 +78,7 @@ public:
 	/// add a new button to the toolbar.
     	void add(int ,bool doclean=true);
 	/// name of func instead of kb_action
-	void add(LString const & , bool doclean=true);
+	void add(string const & , bool doclean=true);
 	/// invokes the n'th icon in the toolbar
 	void push(int);
 	/// activates the toolbar
@@ -86,6 +86,14 @@ public:
 	/// deactivates the toolbar
         void deactivate();
 
+	///
+	static void ToolbarCB(FL_OBJECT*, long);
+	///
+	static void BubbleTimerCB(FL_OBJECT *, long);
+	///
+	static int BubblePost(FL_OBJECT *ob, int event,
+			      FL_Coord mx, FL_Coord my, int key, void *xev);
+
 private:
 	///
 	struct toolbarItem
@@ -95,7 +103,7 @@ private:
 		///
 		int action;
 		///
-		LString help;
+		string help;
 		///
 		FL_OBJECT *icon;
 		///
@@ -104,10 +112,10 @@ private:
 		char **pixmap;
 		///
 		toolbarItem(){
-			next = NULL;
+			next = 0;
 			action = LFUN_NOACTION;
-			icon = NULL;
-			pixmap = NULL;
+			icon = 0;
+			pixmap = 0;
 			IsBitmap = false;
 		}
 		///
@@ -144,21 +152,14 @@ private:
 	bool cleaned;
 
 	///
-	char **getPixmap(kb_action, LString const & arg=LString());
+	char **getPixmap(kb_action, string const & arg=string());
 	/// removes all toolbar buttons from the toolbar.
 	void clean();
-	///
-	static void ToolbarCB(FL_OBJECT*, long);
-	///
-	static void BubbleTimerCB(FL_OBJECT *, long);
-	///
-	static int BubblePost(FL_OBJECT *ob, int event,
-			      FL_Coord mx, FL_Coord my, int key, void *xev);
 
 	/** more...
 	 */
 	void reset(){
-		toollist = NULL;
+		toollist = 0;
 		cleaned = false;
 		
 		lightReset();
